==> wikindx3_2_2.tar.gz: wikindx3/core/browse/BROWSECREATOR.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSECREATOR class
*
* Browse creators as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSECREATOR.php,v 1.5 2005/12/20 07:36:22 sirfragalot Exp $
*****/
class BROWSECREATOR
{
// Constructor
	function BROWSECREATOR($db)
	{
		$this->db = $db;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display creators
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseCreator"));
		$this->sum = $this->surname = $this->prefix = $this->resourceIds = array();
		$this->getCreators('creator1');
		$this->getCreators('creator2');
		$this->getCreators('creator3');
		$this->getCreators('creator4');
		$this->getCreators('creator5');
		if(empty($this->surname))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noCreators");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		asort($this->sum);
		asort($this->surname);
		foreach($this->surname as $id => $surname)
		{
			if(!empty($this->prefix) && array_key_exists($id, $this->prefix))
				$this->surname[$id] = $this->prefix[$id] . ' ' . $surname;
		}
		$creatorSum = $this->sum;
		$creatorSurname = $this->surname;
		$pString = MISC::p($this->bib, "hint") . 
			MISC::pBrowse($this->process($creatorSum, $creatorSurname), "center");
		$this->template->setVar('body', $pString);
		return $this->template->process();
	}
// Process and display results
	function process($creatorSum, $creatorSurname)
	{
		$lowestSum = current($creatorSum);
		$highestSum = end($creatorSum);
		foreach($this->surname as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $creatorSum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listCreatorProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $creatorSum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get creators from db
	function getCreators($creator)
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_creator');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_creator'), 
			array('id', $creator), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($creator, $row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add creators to array and sum totals
	function collate($creator, $row)
	{
		foreach(split(",", $row[$creator]) as $key => $value)
		{
			if($value)
				$creators[] = "$value";
		}
		if(!isset($creators))
			return FALSE;
		foreach($creators as $creatorId)
		{
			if(!array_key_exists($row['id'], $this->resourceIds))
				$this->resourceIds[$row['id']][] = $creatorId;
			else if(array_search($creatorId, $this->resourceIds[$row['id']]) !== FALSE)
				continue; // this creator already listed for this resource
			else
				$this->resourceIds[$row['id']][] = $creatorId;
			if(!array_key_exists($creatorId, $this->sum))
				$this->sum[$creatorId] = 1;
			else
				++$this->sum[$creatorId];
			$creatorsCondition[] = "'$creatorId'";
		}
		if(!isset($creatorsCondition))
			return;
		$creatorsCondition = array_unique($creatorsCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $creatorsCondition);
		$recordset = $this->db->select(array('WKX_creator'), array("id", "surname", "prefix"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
		{
			$this->surname[$row['id']] = stripslashes($row['surname']);
			$this->prefix[$row['id']] = stripslashes($row['prefix']);
		}
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/core/browse/BROWSECREATOR.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2006
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSECREATOR class
*
* Browse creators as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSECREATOR.php,v 1.8 2006/04/29 00:44:46 sirfragalot Exp $
*****/
class BROWSECREATOR
{
// Constructor
	function BROWSECREATOR($db, $vars)
	{
		$this->db = $db;
		$this->vars = $vars;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display creators
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseCreator"));
		$this->sum = $this->surname = $this->prefix = $this->resourceIds = array();
		$this->getCreators('creator1');
		$this->getCreators('creator2');
		$this->getCreators('creator3');
		$this->getCreators('creator4');
		$this->getCreators('creator5');
		if(empty($this->surname))
		{
			$pString = MISC::p("&nbsp;") . $this->messages->text("misc", "noCreators");
			$this->template->setVar('body', $pString);
			return $this->template->process();
		}
		natcasesort($this->sum);
		natcasesort($this->surname);
		$this->surname = $this->common->paging($this->vars, $this->surname);
		foreach($this->surname as $id => $surname)
		{
			if(!empty($this->prefix) && array_key_exists($id, $this->prefix))
				$this->surname[$id] = $this->prefix[$id] . ' ' . $surname;
		}
		$creatorSum = $this->sum;
		$creatorSurname = $this->surname;
		$pString = MISC::p($this->bib, "hint") . $this->common->linksInfo() . 
			MISC::pBrowse($this->process($creatorSum, $creatorSurname), "center");
		$this->template->setVar('body', $pString);
		$this->template->setVar('paging', $this->common->pagingLinks("action=browseCreator"));
		return $this->template->process();
	}
// Process and display results
	function process($creatorSum, $creatorSurname)
	{
		$lowestSum = current($creatorSum);
		$highestSum = end($creatorSum);
		foreach($this->surname as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $creatorSum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listCreatorProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $creatorSum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get creators from db
	function getCreators($creator)
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_creator');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_creator'), 
			array('id', $creator), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($creator, $row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add creators to array and sum totals
	function collate($creator, $row)
	{
		foreach(split(",", $row[$creator]) as $key => $value)
		{
			if($value)
				$creators[] = preg_replace("/{(.*)}/U", "$1", $value);
		}
		if(!isset($creators))
			return FALSE;
		foreach($creators as $creatorId)
		{
			if(!array_key_exists($row['id'], $this->resourceIds))
				$this->resourceIds[$row['id']][] = $creatorId;
			else if(array_search($creatorId, $this->resourceIds[$row['id']]) !== FALSE)
				continue; // this creator already listed for this resource
			else
				$this->resourceIds[$row['id']][] = $creatorId;
			if(!array_key_exists($creatorId, $this->sum))
				$this->sum[$creatorId] = 1;
			else
				++$this->sum[$creatorId];
			$creatorsCondition[] = "'$creatorId'";
		}
		if(!isset($creatorsCondition))
			return;
		$creatorsCondition = array_unique($creatorsCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $creatorsCondition);
		$recordset = $this->db->select(array('WKX_creator'), array("id", "surname", "prefix"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
		{
			$this->surname[$row['id']] = preg_replace("/{(.*)}/U", "$1", stripslashes($row['surname']));
			$this->prefix[$row['id']] = preg_replace("/{(.*)}/U", "$1", stripslashes($row['prefix']));
		}
	}
}
?>
